@@ -1,4 +1,4 @@
-/* $Id: //depot/Teapop/0.3/include/pop_strings.h#6 $ */
+/* $Id: //depot/Teapop/0.3/include/pop_strings.h#7 $ */
 
 /*
  * Copyright (c) 1999-2001 ToonTown Consulting
@@ -82,6 +82,6 @@
 #define POP_QUIT_OK	"It has been a pleasure serving you."
 #define POP_QUIT_ERR	"Ehum..Bye"
 
-char *pop_string_find __P((char *, char *));
+char *pop_string_find __P((const char *, const char *));
 int pop_string_dtot __P((const char *));
 #endif				/* __POP_STRINGS_H__ */
