@@ -1,4 +1,4 @@
-/* $Id: //depot/Teapop/0.3/include/teapop.h#6 $ */
+/* $Id: //depot/Teapop/0.3/include/teapop.h#7 $ */
 
 /*
  * Copyright (c) 1999-2002 ToonTown Consulting
@@ -126,6 +126,8 @@ typedef struct _pop_info {
 	int mboxperm;
 	int expire;
 	int ssl;
+	int softlock;
+	unsigned short localport;
 	char drachost[BIGSTRING];
 	char apopstr[BIGSTRING];
 	char userid[BIGSTRING];
