@@ -1,7 +1,7 @@
-/* $Id: //depot/Teapop/0.3/teapop/pop_dele.c#6 $ */
+/* $Id: //depot/Teapop/0.3/teapop/pop_dele.c#7 $ */
 
 /*
- * Copyright (c) 1999-2001 ToonTown Consulting
+ * Copyright (c) 1999-2003 ToonTown Consulting
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -29,6 +29,8 @@
 
 #include "config.h"
 
+#include <sys/types.h>
+
 #ifdef HAVE_SYS_FILE_H
 #include <sys/file.h>
 #endif /* HAVE_SYS_FILE_H */
@@ -36,10 +38,15 @@
 #include <fcntl.h>
 #include <signal.h>
 #include <stdio.h>
+#include <string.h>
 #include <syslog.h>
+#include <time.h>
 #include <unistd.h>
 
 #include "teapop.h"
+#ifdef NEED_FLOCK
+#include "flock.h"
+#endif
 #include "pop_socket.h"
 #include "pop_strings.h"
 
@@ -54,6 +61,7 @@ pop_update(pinfo)
 	FILE *fd;
 	POP_MSG *curmsg;
 	sigset_t smask, osmask;
+	time_t expiredate = 0;
 
 	/*
 	 * Ok, there's a goto here...So sue me =p
@@ -71,6 +79,11 @@ pop_update(pinfo)
 	sigemptyset((sigset_t *)&osmask);
 	sigprocmask(SIG_BLOCK, (sigset_t *)&smask, (sigset_t *)&osmask);
 
+	/* All messages created before this date should be deleted */
+	if (pinfo->expire != 0)
+		expiredate = (time_t)(time(NULL) -
+		    (time_t)(pinfo->expire * 86400));
+
 	if (pinfo->mboxtype == 0) {
 #ifdef FLOCK
 		flock(fileno(pinfo->mbox), LOCK_SH|LOCK_NB);
@@ -87,7 +100,9 @@ pop_update(pinfo)
 			}
 			if (!(curmsg->flags & MSG_DELETED) &&
 			    !((curmsg->flags & MSG_READ) &&
-			    (pinfo->autodelete > 0))) {
+			    (pinfo->autodelete > 0)) &&
+			    !(pinfo->expire != 0 &&
+			    (curmsg->created < expiredate))) {
 				for (i = 0UL; i < curmsg->realsize;
 				    i += strlen(buf)) {
 					fgets(buf, sizeof(buf), fd);
@@ -120,7 +135,9 @@ pop_update(pinfo)
 			}
 			if (!(curmsg->flags & MSG_DELETED) &&
 			    !((curmsg->flags & MSG_READ) &&
-			    (pinfo->autodelete > 0))) {
+			    (pinfo->autodelete > 0)) && 
+			    !(pinfo->expire != 0 &&
+			    (curmsg->created < expiredate))) {
 				left++;
 				leftsize += curmsg->size;
 			} else {
@@ -150,5 +167,5 @@ eofupdate:
 		    pinfo->userid, pinfo->remoteip, retr, retrsize, dele,
 		    delesize, left, leftsize);
 
-	return 0;
+	return (0);
 }
