@@ -1,7 +1,7 @@
-/* $Id: //depot/Teapop/0.3/teapop/pop_mbox.c#5 $ */
+/* $Id: //depot/Teapop/0.3/teapop/pop_mbox.c#6 $ */
 
 /*
- * Copyright (c) 1999-2001 ToonTown Consulting
+ * Copyright (c) 1999-2003 ToonTown Consulting
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -27,6 +27,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <sys/types.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -44,15 +46,18 @@
 #include <md5.h>
 #endif
 
+time_t pop_string_mktime(const char *);
+
 void
 pop_mbox_get_status(pinfo)
 	POP_INFO *pinfo;
 {
 	char buf[1024], *ptr, *tmpstr;
 	int doingline = 0, isimap = 0, gotuidl = 0, gotmsg = 0, inheader = 1;
-	int counter;
+	int counter, i;
 	unsigned long lastftell;
 	unsigned char digest[16];
+	time_t timestamp;
 
 	MD5_CTX	ctx;
 	POP_MSG *curmsg, *lastmsg;
@@ -73,7 +78,7 @@ pop_mbox_get_status(pinfo)
 		syslog(LOG_CRIT, "memory problems");
 		return;
 	}
-	bzero(curmsg, sizeof(POP_MSG));
+	memset(curmsg, 0, sizeof(POP_MSG));
 
 	rewind(pinfo->mbox);
 	lastftell = 0;
@@ -84,18 +89,20 @@ pop_mbox_get_status(pinfo)
 			break;
 
 		/* Check if it's a new letter */
-		if (!strncmp(buf, "From ", 5) && !doingline) {
+		if (!strncmp(buf, "From ", 5) && !doingline &&
+		    ((timestamp = pop_string_mktime(buf)) != 0)) {
 			MD5Final(digest, &ctx);
 			if (gotmsg == 0 || (isimap == 1 &&
 			    pinfo->ignoreimap == 1)) {
 				/* It's UW-IMAPs message, ignore */
 				isimap = 0;
-				bzero(curmsg, sizeof(POP_MSG));
+				memset(curmsg, 0, sizeof(POP_MSG));
 				curmsg->offset = lastftell =
 				    (unsigned long)ftell(pinfo->mbox);
 				curmsg->realsize = (unsigned long)strlen(buf);
 				curmsg->som = (unsigned long)
 				    (lastftell - curmsg->realsize);
+				curmsg->created = timestamp;
 				MD5Init(&ctx);
 				MD5Update(&ctx, (unsigned char *)buf,
 				    strlen(buf));
@@ -121,12 +128,13 @@ pop_mbox_get_status(pinfo)
 				syslog(LOG_CRIT, "memory problems");
 				return;
 			}
-			bzero(curmsg, sizeof(POP_MSG));
+			memset(curmsg, 0, sizeof(POP_MSG));
 
 			curmsg->som = (unsigned long)lastftell;
 			curmsg->offset = lastftell =
 			    (unsigned long)ftell(pinfo->mbox);
 			curmsg->realsize = (unsigned long)strlen(buf);
+			curmsg->created = timestamp;
 			inheader = 1;
 			gotuidl = 0;
 			MD5Init(&ctx);
@@ -139,10 +147,23 @@ pop_mbox_get_status(pinfo)
 		    pinfo->ignoreimap == 1 && !strncmp(buf, "X-IMAP: ", 8))
 			isimap = 1;
 
-		if (buf[strlen(buf)-1] == '\n')
+		/* Find all NULL characters and replace with questionmarks */
+		i = strlen(buf);
+		while ((i == 0 || buf[i-1] != '\n') && i < (sizeof(buf) - 1)) {
+			buf[i] = '?';
+			i = strlen(buf);
+		}
+
+		/*
+		 * If line only ends with LF, we need to add one to the size
+		 * since we will be sending CRLF to the client.
+		 * Note we need to check that the number of characters in
+		 * buf is high enough (found in i) to not cause buffer
+		 * underflow.
+		 */
+		if ((i > 0 && buf[i-1] == '\n') && (i < 1 || buf[i-2] != '\r'))
 			curmsg->size++;
-		else if (strlen(buf) != sizeof(buf))
-			buf[strlen(buf)] = '?';
+
 		curmsg->size += strlen(buf);
 		curmsg->realsize += strlen(buf);
 
