@@ -1,4 +1,4 @@
-/* $Id: //depot/Teapop/0.3/teapop/pop_passwd.c#5 $ */
+/* $Id: //depot/Teapop/0.3/teapop/pop_passwd.c#6 $ */
 
 /*
  * Copyright (c) 1999-2003 ToonTown Consulting
@@ -143,6 +143,10 @@ pop_read_pwdinfo(pinfo)
 		strcpy(tmpauth->gid, "+");
 
 		pinfo->firstauth = tmpauth;
+
+		syslog(LOG_NOTICE,
+		    "%s not found; using built-in authentication schema.",
+		    PWDINFO);
 		return (0);
 	}
 
