@@ -1,4 +1,4 @@
-/* $Id: //depot/Teapop/0.3/teapop/pop_strings.c#4 $ */
+/* $Id: //depot/Teapop/0.3/teapop/pop_strings.c#5 $ */
 
 /*
  * Copyright (c) 2000-2003 ToonTown Consulting
@@ -40,28 +40,27 @@
 #include "teapop.h"
 #include "pop_strings.h"
 
+/*
+ * Function : pop_string_find
+ * Arguments: const char *string, *tok
+ * Returns  : Pointer to where first token character is found in string
+ */
 char *
 pop_string_find(string, tok)
-	char *string, *tok;
+const char *string, *tok;
 {
 	char *buf, *ptr;
 	unsigned int i;
 
-	if ((buf = malloc(sizeof(char) * (strlen(string) + 1))) == NULL)
-		return (NULL);
-
-	(void)strcpy(buf, string);
+	buf = (char *)&string[strlen(string)];
 
 	for (i = 0; i < (unsigned int)strlen(tok); i++) {
-		ptr = strchr(buf, tok[i]);
-		if (ptr != NULL)
-			*ptr = '\0';
+		ptr = strchr(string, tok[i]);
+		if ((ptr != NULL) && (ptr < buf))
+			buf = ptr;
 	}
 
-	i = (unsigned int)strlen(buf);
-
-	free(buf);
-	return (string+i);
+	return (buf);
 }
 
 /*
